===========
 Changelog
===========

2.9 (2018-10-13)
================

- Improve naming of import fields and add descriptions to them.

- Fix wording mess of import file readers, they are now named as file formats.

- Update to changes in test infrastructure in `icemac.addressbook >= 8.0`.

- Change installation procedure from `bootstrap.py` to `virtualenv`,
  see `README.txt`.


2.8 (2018-08-03)
================

- Update to changes in test infrastructure in `icemac.addressbook >= 7.0`.

- Change license from ZPL to MIT.


2.7 (2017-12-26)
================

- Add breadcrumbs.

- Change `zope.interface.implements[Only]` and `zope.component.adapts` to
  class decorators.

- Also release as wheel.


Previous versions
=================

See ``OLD_CHANGES.rst`` inside the package.
